@@ -37,6 +37,7 @@ import org.eclipse.che.api.factory.server.scm.exception.ScmUnauthorizedException
 import org.eclipse.che.api.factory.server.scm.exception.UnknownScmProviderException;
 import org.eclipse.che.api.factory.server.scm.exception.UnsatisfiedScmPreconditionException;
 import org.eclipse.che.api.workspace.server.spi.InfrastructureException;
+import org.eclipse.che.commons.annotation.Nullable;
 import org.eclipse.che.commons.env.EnvironmentContext;
 import org.eclipse.che.commons.lang.NameGenerator;
 import org.eclipse.che.commons.lang.StringUtils;
@@ -140,7 +141,21 @@ public class KubernetesPersonalAccessTokenManager implements PersonalAccessToken
   public Optional<PersonalAccessToken> get(Subject cheUser, String scmServerUrl)
       throws ScmConfigurationPersistenceException, ScmUnauthorizedException,
           ScmCommunicationException {
+    return doGetPersonalAccessToken(cheUser, null, scmServerUrl);
+  }
 
+  @Override
+  public Optional<PersonalAccessToken> get(
+      Subject cheUser, String oAuthProviderName, @Nullable String scmServerUrl)
+      throws ScmConfigurationPersistenceException, ScmUnauthorizedException,
+          ScmCommunicationException {
+    return doGetPersonalAccessToken(cheUser, oAuthProviderName, scmServerUrl);
+  }
+
+  private Optional<PersonalAccessToken> doGetPersonalAccessToken(
+      Subject cheUser, @Nullable String oAuthProviderName, @Nullable String scmServerUrl)
+      throws ScmConfigurationPersistenceException, ScmUnauthorizedException,
+          ScmCommunicationException {
     try {
       for (KubernetesNamespaceMeta namespaceMeta : namespaceFactory.list()) {
         List<Secret> secrets =
@@ -152,8 +167,14 @@ public class KubernetesPersonalAccessTokenManager implements PersonalAccessToken
           Map<String, String> annotations = secret.getMetadata().getAnnotations();
           String trimmedUrl = StringUtils.trimEnd(annotations.get(ANNOTATION_SCM_URL), '/');
           if (annotations.get(ANNOTATION_CHE_USERID).equals(cheUser.getUserId())
-              && trimmedUrl.equals(StringUtils.trimEnd(scmServerUrl, '/'))) {
-            PersonalAccessToken token =
+              && (oAuthProviderName == null
+                  || oAuthProviderName.equals(
+                      annotations.get(ANNOTATION_SCM_PERSONAL_ACCESS_TOKEN_NAME)))
+              && (scmServerUrl == null
+                  || trimmedUrl.equals(StringUtils.trimEnd(scmServerUrl, '/')))) {
+            String token =
+                new String(Base64.getDecoder().decode(secret.getData().get("token"))).trim();
+            PersonalAccessToken personalAccessToken =
                 new PersonalAccessToken(
                     trimmedUrl,
                     annotations.get(ANNOTATION_CHE_USERID),
@@ -162,9 +183,9 @@ public class KubernetesPersonalAccessTokenManager implements PersonalAccessToken
                     annotations.get(ANNOTATION_SCM_USERID),
                     annotations.get(ANNOTATION_SCM_PERSONAL_ACCESS_TOKEN_NAME),
                     annotations.get(ANNOTATION_SCM_PERSONAL_ACCESS_TOKEN_ID),
-                    new String(Base64.getDecoder().decode(secret.getData().get("token"))));
-            if (scmPersonalAccessTokenFetcher.isValid(token)) {
-              return Optional.of(token);
+                    token);
+            if (scmPersonalAccessTokenFetcher.isValid(personalAccessToken)) {
+              return Optional.of(personalAccessToken);
             } else {
               // Removing token that is no longer valid. If several tokens exist the next one could
               // be valid. If no valid token can be found, the caller should react in the same way
