@@ -33,10 +33,7 @@ public class GitlabAuthorizingFileContentProviderTest {
   public void shouldExpandRelativePaths() throws Exception {
     URLFetcher urlFetcher = Mockito.mock(URLFetcher.class);
     GitlabUrl gitlabUrl =
-        new GitlabUrl()
-            .withHostName("https://gitlab.net")
-            .withUsername("eclipse")
-            .withProject("che");
+        new GitlabUrl().withHostName("https://gitlab.net").withSubGroups("eclipse/che");
     FileContentProvider fileContentProvider =
         new GitlabAuthorizingFileContentProvider(gitlabUrl, urlFetcher, personalAccessTokenManager);
     var personalAccessToken = new PersonalAccessToken("foo", "che", "my-token");
@@ -52,8 +49,7 @@ public class GitlabAuthorizingFileContentProviderTest {
   @Test
   public void shouldPreserveAbsolutePaths() throws Exception {
     URLFetcher urlFetcher = Mockito.mock(URLFetcher.class);
-    GitlabUrl gitlabUrl =
-        new GitlabUrl().withHostName("gitlab.net").withUsername("eclipse").withProject("che");
+    GitlabUrl gitlabUrl = new GitlabUrl().withHostName("gitlab.net").withSubGroups("eclipse/che");
     FileContentProvider fileContentProvider =
         new GitlabAuthorizingFileContentProvider(gitlabUrl, urlFetcher, personalAccessTokenManager);
     String url =
